Enum WalkState
enum WalkState
WalkState is used in the parallel recursive directory iterator to indicate whether walking should continue as normal, skip descending into a particular directory or quit the walk entirely.
Variants
-
Continue Continue walking as normal.
-
Skip If the directory entry given is a directory, don't descend into it. In all other cases, this has no effect.
-
Quit Quit the entire iterator as soon as possible.
Note that this is an inherently asynchronous action. It is possible for more entries to be yielded even after instructing the iterator to quit.
Implementations
impl Clone for WalkState
fn clone(self: &Self) -> WalkState
impl Copy for WalkState
impl Debug for WalkState
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Eq for WalkState
impl Freeze for WalkState
impl PartialEq for WalkState
fn eq(self: &Self, other: &WalkState) -> bool
impl RefUnwindSafe for WalkState
impl Send for WalkState
impl StructuralPartialEq for WalkState
impl Sync for WalkState
impl Unpin for WalkState
impl UnsafeUnpin for WalkState
impl UnwindSafe for WalkState
impl<T> Any for WalkState
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for WalkState
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for WalkState
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for WalkState
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for WalkState
fn from(t: T) -> TReturns the argument unchanged.
impl<T> Pointable for WalkState
unsafe fn init(init: <T as Pointable>::Init) -> usizeunsafe fn deref<'a>(ptr: usize) -> &'a Tunsafe fn deref_mut<'a>(ptr: usize) -> &'a mut Tunsafe fn drop(ptr: usize)
impl<T> ToOwned for WalkState
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T, U> Into for WalkState
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for WalkState
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for WalkState
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>