Function gitconfig_excludes_path
fn gitconfig_excludes_path() -> Option<PathBuf>
Return the file path of the current environment's global gitignore file.
Note that the file path returned may not exist.
gitconfig_excludes_pathfn gitconfig_excludes_path() -> Option<PathBuf>
Return the file path of the current environment's global gitignore file.
Note that the file path returned may not exist.