Error

Enum Error 

pub enum Error {
    Partial(Vec<Error>),
    WithLineNumber {
        line: u64,
        err: Box<Error>,
    },
    WithPath {
        path: PathBuf,
        err: Box<Error>,
    },
    WithDepth {
        depth: usize,
        err: Box<Error>,
    },
    Loop {
        ancestor: PathBuf,
        child: PathBuf,
    },
    Io(Error),
    Glob {
        glob: Option<String>,
        err: String,
    },
    UnrecognizedFileType(String),
    InvalidDefinition,
}
Represents an error that can occur when parsing a gitignore file.

Variants



Partial(Vec<Error>)

A collection of “soft” errors. These occur when adding an ignore file partially succeeded.



WithLineNumber

An error associated with a specific line number.

Fields

line: u64

The line number.

err: Box<Error>

The underlying error.



WithPath

An error associated with a particular file path.

Fields

path: PathBuf

The file path.

err: Box<Error>

The underlying error.



WithDepth

An error associated with a particular directory depth when recursively walking a directory.

Fields

depth: usize

The directory depth.

err: Box<Error>

The underlying error.



Loop

An error that occurs when a file loop is detected when traversing symbolic links.

Fields

ancestor: PathBuf

The ancestor file path in the loop.

child: PathBuf

The child file path in the loop.



Io(Error)

An error that occurs when doing I/O, such as reading an ignore file.



Glob

An error that occurs when trying to parse a glob.

Fields

glob: Option<String>

The original glob that caused this error. This glob, when available, always corresponds to the glob provided by an end user. e.g., It is the glob as written in a .gitignore file.

(This glob may be distinct from the glob that is actually compiled, after accounting for gitignore semantics.)

err: String

The underlying glob error as a string.



UnrecognizedFileType(String)

A type selection for a file type that is not defined.



InvalidDefinition

A user specified file type definition could not be parsed.

Implementations

Source

impl Error

pub fn is_partial(&self) -> bool

Returns true if this is a partial error.

A partial error occurs when only some operations failed while others may have succeeded. For example, an ignore file may contain an invalid glob among otherwise valid globs.

pub fn is_io(&self) -> bool

Returns true if this error is exclusively an I/O error.

pub fn io_error(&self) -> Option<&Error>

Inspect the original io::Error if there is one.

None is returned if the Error doesn’t correspond to an io::Error. This might happen, for example, when the error was produced because a cycle was found in the directory tree while following symbolic links.

This method returns a borrowed value that is bound to the lifetime of the Error. To obtain an owned value, the into_io_error can be used instead.

This is the original io::Error and is not the same as impl From<Error> for std::io::Error which contains additional context about the error.

pub fn into_io_error(self) -> Option<Error>

Similar to io_error except consumes self to convert to the original io::Error if one exists.

pub fn depth(&self) -> Option<usize>

Returns a depth associated with recursively walking a directory (if this error was generated from a recursive directory iterator).