Struct Walk
struct Walk { ... }
Walk is a recursive directory iterator over file paths in one or more directories.
Only file and directory paths matching the rules are returned. By default,
ignore files like .gitignore are respected. The precise matching rules
and precedence is explained in the documentation for WalkBuilder.
Implementations
impl Walk
fn new<P: AsRef<Path>>(path: P) -> WalkCreates a new recursive directory iterator for the file path given.
Note that this uses default settings, which include respecting
.gitignorefiles. To configure the iterator, useWalkBuilderinstead.
impl Freeze for Walk
impl FusedIterator for Walk
impl Iterator for Walk
fn next(self: &mut Self) -> Option<Result<DirEntry, Error>>
impl RefUnwindSafe for Walk
impl Send for Walk
impl Sync for Walk
impl Unpin for Walk
impl UnsafeUnpin for Walk
impl UnwindSafe for Walk
impl<I> IntoIterator for Walk
fn into_iter(self: Self) -> I
impl<T> Any for Walk
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for Walk
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for Walk
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> From for Walk
fn from(t: T) -> TReturns the argument unchanged.
impl<T> Pointable for Walk
unsafe fn init(init: <T as Pointable>::Init) -> usizeunsafe fn deref<'a>(ptr: usize) -> &'a Tunsafe fn deref_mut<'a>(ptr: usize) -> &'a mut Tunsafe fn drop(ptr: usize)
impl<T, U> Into for Walk
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for Walk
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for Walk
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>