Trait ParallelVisitor

trait ParallelVisitor: Send

Receives files and directories for the current thread.

Setup for the traversal can be implemented as part of ParallelVisitorBuilder::build. Teardown when traversal finishes can be implemented by implementing the Drop trait on your traversal type.

Required Methods

fn visit(self: &mut Self, entry: Result<DirEntry, Error>) -> WalkState

Receives files and directories for the current thread. This is called once for every directory entry visited by traversal.