Trait ParallelVisitorBuilder

trait ParallelVisitorBuilder<'s>

A builder for constructing a visitor when using WalkParallel::visit. The builder will be called for each thread started by WalkParallel. The visitor returned from each builder is then called for every directory entry.

Required Methods

fn build(self: &mut Self) -> Box<dyn ParallelVisitor + 's>

Create per-thread ParallelVisitors for WalkParallel.

Implementors